@@ -3,6 +3,9 @@ summary.selection <- function(object, ...) {
 
    if( object$method == "ml" ) {
       s <- NextMethod( "summary", object, ...)
+      stdd <- sqrt( diag( vcov( object, part = "full" ) ) )
+      estcoef <- coef( object, part="full" )
+      s$estimate <- coefTable( estcoef, stdd, object$param$df )
    } else if( object$method == "2step" )  {
       s <- list()  # list for results that will be returned
       RSq <- function(model, intercept) {
@@ -49,8 +52,12 @@ summary.selection <- function(object, ...) {
    }
    s$param    <- object$param
    s$tobitType <- object$tobitType
+   s$outcomeVar <- object$outcomeVar
    s$method <- object$method
    s$activePar <- activePar(object)
+   s$intervals <- object$intervals
+   s$coefAll   <- object$coefAll
+   s$vcovAll   <- object$vcovAll
    class( s ) <- c( "summary.selection", class( s ) )
    return( s )
 }
@@ -62,6 +69,9 @@ print.summary.selection <- function(x,
 
    cat("--------------------------------------------\n")
    cat("Tobit", x$tobitType, "model" )
+   if( isTRUE( x$outcomeVar %in% c( "interval", "binary" ) ) ) {
+      cat( " with", x$outcomeVar, "outcome" )
+   }
    if( x$tobitType == 2 ) {
       cat( " (sample selection model)\n" )
    } else {
@@ -95,6 +105,10 @@ print.summary.selection <- function(x,
       }
       else
          stop("Tobit type must be either '2', '5', or 'treatment'")
+      if( !is.null( x$intervals ) ) {
+         cat( "Intervals of the dependent variable of the outcome equation:\n")
+         print( x$intervals )
+      }
       cat(sum(x$activePar), "free parameters" )
       cat( " (df = ", x$param$df, ")\n", sep="")
       if(part == "full") {
@@ -144,6 +158,7 @@ print.summary.selection <- function(x,
          printCoefmat( x$estimate[ x$param$index$errTerms,,drop=FALSE],
             digits = digits )
       }
+
    }
    cat("--------------------------------------------\n")
    invisible( x )
