@@ -1,3 +1,8 @@
+### Testing 'selection' function
+### Includes following tests:
+###
+### * factor as dependent variable (yes/no)
+### 
 library( "sampleSelection" )
 library( "mvtnorm" )
 library( "lmtest" )
@@ -293,7 +298,7 @@ all.equal( mmoTestTobit5Ml, mmoTestTobit5MlMm )
 testTobit5MlMf <- selection( ys~xs, list( yo1 ~ xo1, yo2 ~ xo2 ),
    method = "ml", mfs = TRUE, mfo = TRUE, data = t5Dat )
 mfTestTobit5MlMf <- model.frame( testTobit5MlMf )
-all.equal( mfTestTobit5Ml, mfTestTobit5MlMf )
+all.equal( mfTestTobit5Ml, mfTestTobit5MlMf, check.attributes = FALSE )
 
 # return just the model.frame
 all.equal( selection( ys~xs, list( yo1 ~ xo1, yo2 ~ xo2 ),
@@ -351,25 +356,30 @@ mfTestTobit5SMl <- model.frame( testTobit5SMl )
 print( mfTestTobit5SMl )
 logLik( testTobit5SMl )
 
-# factors as dependent variable (from Achim Zeileis)
+## ---------- factors as dependent variable (from Achim Zeileis) ----------
+## it should not matter at all as the underlying models remain binary equivalent
+## However, as the estimation previously did not work with a dependent "factor"
+## variable, these tests should avoid that this problem occurs again 
+### 2-step estimation
 testTobit5FacTwoStep <- selection( factor( ys ) ~ xs,
    list( yo1 ~ xo1, yo2 ~ xo2 ), method = "2step", data = t5Dat )
 all.equal( testTobit5FacTwoStep[ -c( 8, 9 ) ], testTobit5TwoStep[ -c( 8, 9 ) ] )
+## use yes/no as the outcome variable
 testTobit5YesTwoStep <- selection( factor( ys, labels = c( "no", "yes" ) ) ~ xs,
    list( yo1 ~ xo1, yo2 ~ xo2 ), method = "2step", data = t5Dat )
 all.equal( testTobit5YesTwoStep[ -c( 8, 9, 17 ) ],
    testTobit5TwoStep[ -c( 8, 9, 17 ) ] )
 all.equal( testTobit5YesTwoStep$param[ -c( 12 ) ],
    testTobit5TwoStep$param[ -c( 12 ) ] )
-
+### ML estimation
 testTobit5FacMl <- selection( factor( ys ) ~ xs,
    list( yo1 ~ xo1, yo2 ~ xo2 ), data = t5Dat )
-all.equal( testTobit5FacMl[ -c( 15, 18, 19 ) ],
-   testTobit5Ml[ -c( 15, 18, 19 ) ] )
+all.equal( testTobit5FacMl[ -c( 16, 19, 20 ) ],
+   testTobit5Ml[ -c( 16, 19, 20 ) ] )
 testTobit5YesMl <- selection( factor( ys, labels = c( "no", "yes" ) ) ~ xs,
    list( yo1 ~ xo1, yo2 ~ xo2 ), data = t5Dat )
-all.equal( testTobit5YesMl[ -c( 15, 17, 18, 19 ) ],
-   testTobit5Ml[ -c( 15, 17, 18, 19 ) ] )
+all.equal( testTobit5YesMl[ -c( 16, 18, 19, 20 ) ],
+   testTobit5Ml[ -c( 16, 18, 19, 20 ) ] )
 all.equal( testTobit5YesMl$param[ -c( 10 ) ], testTobit5Ml$param[ -c( 10 ) ] )
 
 # with pre-defined list of outcome equations (works since revision 1420)
@@ -385,12 +395,12 @@ testTobit5LiYesTwoStep <- selection( factor( ys, labels = c( "no", "yes" ) )
 all.equal( testTobit5LiYesTwoStep[ -8 ],  testTobit5YesTwoStep[ -8 ] )
 
 testTobit5LiMl <- selection( ys ~ xs, oList, data = t5Dat )
-all.equal( testTobit5LiMl[ -18 ],  testTobit5Ml[ -18 ] )
+all.equal( testTobit5LiMl[ -19 ],  testTobit5Ml[ -19 ] )
 testTobit5LiFacMl <- selection( factor( ys ) ~ xs, oList, data = t5Dat )
-all.equal( testTobit5LiFacMl[ -18 ],  testTobit5FacMl[ -18 ] )
+all.equal( testTobit5LiFacMl[ -19 ], testTobit5FacMl[ -19 ] )
 testTobit5LiYesMl <- selection( factor( ys, labels = c( "no", "yes" ) )
    ~ xs, oList, data = t5Dat )
-all.equal( testTobit5LiYesMl[ -18 ],  testTobit5YesMl[ -18 ] )
+all.equal( testTobit5LiYesMl[ -19 ],  testTobit5YesMl[ -19 ] )
 
 # return just the model.frame
 selection( factor( ys ) ~ xs, list( yo1 ~ xo1, yo2 ~ xo2 ),
@@ -413,7 +423,7 @@ all.equal( testTobit5TwoStepWe[-8], testTobit5TwoStep[-8] )
 
 testTobit5MlWe <- selection( ys ~ xs, list( yo1 ~ xo1, yo2 ~ xo2), 
    method = "ml", weights = rep( 0.5, N ), data = t5Dat )
-all.equal( testTobit5MlWe[-18], testTobit5Ml[-18] )
+all.equal( testTobit5MlWe[-19], testTobit5Ml[-19] )
 
 ## data directly in the workspace
 ys <- t5Dat$ys
@@ -652,8 +662,7 @@ all.equal( mmoTestTobit2Ml, mmoTestTobit2MlMm )
 testTobit2MlMf <- selection( ys ~ xs, yo ~ xo, method = "ml",
    mfs = TRUE, mfo = TRUE, data = t2Dat )
 mfTestTobit2MlMf <- model.frame( testTobit2MlMf )
-all.equal( mfTestTobit2Ml, mfTestTobit2MlMf )
-                           # attributes (terms) differ here, I don't exactly know how to improve that
+all.equal( mfTestTobit2Ml, mfTestTobit2MlMf, check.attributes = FALSE )
 
 # return just the model.frame
 all.equal( selection( ys ~ xs, yo ~ xo, method = "model.frame", data = t2Dat ),
@@ -746,7 +755,7 @@ all.equal(
    residuals( testTobit2TwoStep, part = "selection", type = "response" ) )
 
 testTobit2FacMl <- selection( factor( ys ) ~ xs, yo ~ xo, data = t2Dat )
-all.equal( testTobit2FacMl[-c(18,19)], testTobit2Ml[-c(18,19)] )
+all.equal( testTobit2FacMl[-c(19,20)], testTobit2Ml[-c(19,20)] )
 all.equal( fitted( testTobit2FacMl, part = "selection" ),
    fitted( testTobit2Ml, part = "selection" ) )
 all.equal(
@@ -761,7 +770,7 @@ all.equal(
 
 testTobit2YesMl <- selection( factor( ys, labels = c( "no", "yes" ) ) ~ xs,
    yo ~ xo, data = t2Dat )
-all.equal( testTobit2YesMl[-c(17:19)], testTobit2Ml[-c(17:19)] )
+all.equal( testTobit2YesMl[-c(18:20)], testTobit2Ml[-c(18:20)] )
 all.equal( testTobit2YesMl$param[-9], testTobit2Ml$param[-9] )
 all.equal( fitted( testTobit2YesMl, part = "selection" ),
    fitted( testTobit2Ml, part = "selection" ) )
@@ -792,8 +801,8 @@ testTobit2MlStart <- selection( ys ~ xs, yo ~ xo, data = t2Dat, method = "ml",
    start = init )
 print( summary( testTobit2MlStart ) )
                            # Note: should be only 1 iteration
-all.equal( testTobit2Ml[ -c(2,5,6,9,15,16,18)],
-   testTobit2MlStart[ -c(2,5,6,9,15,16,18)], tol = 1e-5 )
+all.equal( testTobit2Ml[ -c(2,5,6,9,16,17,19)],
+   testTobit2MlStart[ -c(2,5,6,9,16,17,19)], tol = 1e-5 )
 
 ## Chris Hane: dummy variable (factor) as explanatory variable
 t2Dat$xF <- rbinom( nrow( t2Dat ), 1, 0.5 )
